######################################################
#### Section1 -- Tour of RStudio

######################################################
#### Section2 -- Environment

# Clear the global environment  
rm(list = ls())
ls()

# Check the working directory  
getwd()

# Set your working directory  
setwd("/Users/allison/Desktop/R_workshop")

######################################################
#### Section3  -- Reading the data file and checking the input

# Read the data in from a csv file 
# Before generating and saving a file for use in R, check that you've prepared the data (ie no spaces in column headers)
count_table <- read.csv("GSE62902.csv", row.names = 1)

# Does count_table have the column headers that we would expect?
# Note that the first line includes sample dosages. This is followed by gene count data.
head(count_table)

# Does count_table have the dimensions that we would expect?
# Dimensions: number of observations (rows) and number of variables (columns)
dim(count_table)

# Check the end of the file
# Note that alignment data is displayed in the last 5 lines
tail(count_table)

# Does count_table contain a data type that we would expect?
# Get information about the structure of the data 
class(count_table)
str(count_table)

# Does the data frame contain any NA values?
anyNA(count_table)

# Find the number of NA values in the data frame
sum(is.na(count_table))

# List rows that have NA 
count_table[!complete.cases(count_table), ]

######################################################
#### Section 4 -- Data frame indices

# One can look at specific elements within a data frame
# For example, what is the count for the gene in row 2, column 1
head(count_table, n = 3)
count_table[2, 1]

# For rows 1:2
count_table[1:2, ]

# For columns 1 and 3
ex1 <- count_table[, c(1, 3)]
names(ex1)

# For columns 1 and 3
ex2 <- count_table[c(1, 3)]
names(ex2)

# For columns 1 and 3, selecting by name
ex3 <- count_table[c("GSM1535917", "GSM1535919")]
names(ex3)

# Extracting single columns
# Column 1, v1
ex4 <- count_table[1]
head(ex4)

# Column 1, v2
ex5 <- count_table[, 1]
head(ex5)

# Column 1, v2. Add argument drop=FALSE 
ex6 <- count_table[, 1, drop = FALSE]
head(ex6)

######################################################
#### Section 5 -- Extracting data
### By row

# Examine the end of the file where there are 5 rows of alignment data
tail(count_table)

# Make a subset of the data to include just the alignment data by specifying the rows
# One way to find the row number for the start of the alignment data is with the which function
which(row.names(count_table) == "no_feature")

# Get the row number for the last row
nrow(count_table)

# Make a subset of the alignment data by specifying these rows
alignment_subset <- count_table[39181:39185, ]

# Check that the subset has the dimensions that we would expect (5 rows and 45 columns)
dim(alignment_subset)

# We are not going to use this alignment data for now. Let's remove it from the count table   
count_table <- count_table[-(39181:39185), ]
dim(count_table)

# Perhaps though we'd like to use it somewhere else later. Let's save it to a text file.
# Help options: use write.table() with tab to show arguments, help() and help.search() functions
# Alternative - saving objects, workspace
write.table(alignment_subset, "Sample_alignment_data.txt", sep = "\t", quote = FALSE)

################################
### By column

# Let's take another look at the top of the file
head(count_table, n = 3)

# The dosages for the samples are in the first row. 
# We can use this information to extract samples that were treated with specific doses. 
# Let's save the dosage information to a new variable dosage
# Use () to save and view dosage
(dosage <- count_table[1, ])

# Let's look at the max and min dosages observed in this dataset
max(dosage)
min(dosage)

# How many samples have a dose greater than 0? 
length(dosage[dosage > 0])

# One can use the which function to return the indices for those samples that pass this criteria
which(dosage > 0)

# The samples with these indices can be included in a new subset 
ex7 <- count_table[which(dosage > 0)]
dim(ex7)

# Remove the dosage information from count_table 
count_table <- count_table[-1, ]

# count_table now includes only the gene counts (39,179 genes, 45 samples)
head(count_table, n = 3)
tail(count_table, n = 3)
dim(count_table)

# Let's remove the alignment and example subsets from our environment
ls()
rm(alignment_subset, ex1, ex2, ex3, ex4, ex5, ex6, ex7)
ls()

######################################################
#### Section 6 --  Obtaining the mean and sorting a data frame

# Here, we will look at the highest dosage, 30. 
# Use the which function to extract this data
counts_max_dosage <- count_table[which(dosage == 30)]
names(counts_max_dosage)

# Calculate the mean values for the counts for the 5 replicates at this dose
# We will use the apply function to calculate the mean and will save it in a new column $D30_Mean
counts_max_dosage$D30_Mean <- apply(X = counts_max_dosage, MARGIN = 1, FUN = mean)
head(counts_max_dosage, n = 2)

# Sort the data frame based on D30_Mean (descending)
counts_max_dosage <- counts_max_dosage[order(-counts_max_dosage$D30_Mean), ]
head(counts_max_dosage)

# Add a new column D30_order that shows the row order
counts_max_dosage$D30_order <- seq.int(nrow(counts_max_dosage))
head(counts_max_dosage)

# The Ensembl gene IDs are shown in the row names, let's include them as a column
counts_max_dosage$gene_id <- row.names(counts_max_dosage)

# Remove the 5 samples from the data frame
counts_max_dosage <- counts_max_dosage[-(1:5)]

names(counts_max_dosage)
str(counts_max_dosage)

# Perhaps we'd like to get more information about the top 10 genes in this subset. 
# We can retrieve annotations for the genes using the biomaRt package
head(counts_max_dosage, n = 3)

######################################################
#### Section 7 -- Installing packages

# Install biomaRt from bioconductor: https://bioconductor.org/packages/release/bioc/html/biomaRt.html

if (!requireNamespace("BiocManager", quietly = TRUE))
  install.packages("BiocManager")

BiocManager::install("biomaRt")

# Once the package is installed, load the package into our environment
library(biomaRt)

# See the versions of loaded packages
sessionInfo()


# We are going to use some additional packages later on in the workshop, so let's install these packages
install.packages("ggplot2")
install.packages("plotly")
install.packages("ggthemes")

######################################################
#### Section 8 -- Obtaining gene annotations and merging data frames
  
# We will only annotate the top 10 genes here
# Save the first 10 rows to a new data frame called top10
top10 <- counts_max_dosage[1:10, ]

#We will use the mouse mm10 annotations
mm10 <- useMart("ensembl", dataset = "mmusculus_gene_ensembl")

# Here we will add the mgi gene symbol and chromosome (getBM: https://www.rdocumentation.org/packages/biomaRt/versions/2.28.0/topics/getBM)
gene_annotation <- getBM(attributes = c("ensembl_gene_id", "mgi_symbol", "chromosome_name"), filters = "ensembl_gene_id", values = top10$gene_id, mart = mm10)
head(gene_annotation)

# Merge the gene annotations with the top10 data frame 
top10_annotated <- merge(top10, gene_annotation, by.x = "gene_id", by.y = "ensembl_gene_id")
head(top10_annotated)

# Order the data frame based on D30_order (ascending)
# Gene with highest count is Alb
top10_annotated <- top10_annotated[order(top10_annotated$D30_order), ]
head(top10_annotated)

######################################################
#### Section 9  -- Additional comments 
  
### Factors
  
# We didn't discuss categorical variables here but one needs to be careful if converting from factors to numeric
# As an example, if we start with a numeric vector, say the doses that are greater than 1
dose_numeric <- dosage[dosage > 1]
dose_numeric
str(dose_numeric)

# We then decide that we'd like these values to be factors
# We can observe how R stores factors
dose_factor <- as.factor(dose_numeric)
str(dose_factor)

# If we'd like to reverse this conversion and revert to numeric values, we can see that we don't get the original vector
as.numeric(dose_factor)

# One way to get back to the original vector
as.numeric(as.character(dose_factor))


### Reading in files 

# Watch for "#" at the beginning of lines
# The stringsAsFactors argument of data.frame() has a default value of FALSE starting with R 4.0.0 (documented in data.frame() help)
