# Load libraries
library(ggplot2)

# Read the dataset
mydata <- read.csv('~/Desktop/workshop/GSE62902.csv', header = TRUE, row.names = 1)

# Always check data dimensions
dim(mydata)

####### If dataset is not clean, make sure you go through the necessary cleaning steps
# Transpose to have genes (features) in columns and measurements in rows
df <- data.frame(t(mydata))
dim(df)

# Make dose a factor
df$CLASS.DOSE <- factor(df$CLASS.DOSE)
######### END Cleaning Steps ####################

######## BEGIN PLOTTING  ######################
# Scatter Plot with the first 2 genes
ggplot(data=df, aes(x=ENSMUSG00000000001, y=ENSMUSG00000000028)) + geom_point()

# Color it with respect to dose
ggplot(df, aes(ENSMUSG00000000001, ENSMUSG00000000028, colour = CLASS.DOSE)) + geom_point()

# Increase point size
ggplot(df, aes(ENSMUSG00000000001, ENSMUSG00000000028, colour = CLASS.DOSE)) + geom_point(size=3)

# Change point shape for subsetted data (change shape is recommended for 6 or less categories)
selected <- c("0","0.03","0.3","3","30")
df_shape <-   df[df$CLASS.DOSE %in% selected,]
ggplot(df_shape, aes(ENSMUSG00000000001, ENSMUSG00000000028, colour = CLASS.DOSE)) + 
  geom_point(size=3, aes(shape=CLASS.DOSE))

# Putting color as an aesthetic element in geom_point - you get the same plot as when the color 
# was placed in data aesthetics. Careful with the spelling when placed in geom_point()
ggplot(df_shape, aes(ENSMUSG00000000001, ENSMUSG00000000028)) + 
  geom_point(size=3, aes(color = CLASS.DOSE, shape=CLASS.DOSE))

# Boxplots
# Select the first gene
ggplot(df,aes(x=CLASS.DOSE, y=ENSMUSG00000000001, fill=CLASS.DOSE)) +  geom_boxplot()

# Do a coordinate flip to have the boxes horizontal
ggplot(df,aes(x=CLASS.DOSE, y=ENSMUSG00000000001, fill=CLASS.DOSE)) +  geom_boxplot() +
  coord_flip()

# Remove legend and change the x-axis label
ggplot(df,aes(x=CLASS.DOSE, y=ENSMUSG00000000001, fill=CLASS.DOSE)) +  geom_boxplot() +
  coord_flip() + labs(x = "Dose") + theme(legend.position="none")

# Change font size and label orientation
ggplot(df,aes(x=CLASS.DOSE, y=ENSMUSG00000000001, fill=CLASS.DOSE)) +  geom_boxplot() +
  coord_flip() + labs(x = "Dose") + theme(legend.position="none",
                                          text = element_text(size=20), 
                                          axis.text.x = element_text(angle=45, hjust = 1))

# Change the theme for overall looks
ggplot(df,aes(x=CLASS.DOSE, y=ENSMUSG00000000001, fill=CLASS.DOSE)) +  geom_boxplot() +
  coord_flip() + labs(x = "Dose") + theme_bw() + theme(legend.position="none")


ggplot(df,aes(x=CLASS.DOSE, y=ENSMUSG00000000001, fill=CLASS.DOSE)) +  geom_boxplot() +
  coord_flip() + labs(x = "Dose") + theme_classic() + theme(legend.position="none")

ggplot(df,aes(x=CLASS.DOSE, y=ENSMUSG00000000001, fill=CLASS.DOSE)) +  geom_boxplot() +
  coord_flip() + labs(x = "Dose") + theme_grey() + theme(legend.position="none")

# More custom themes are available in ggthemes
library(ggthemes)

ggplot(df,aes(x=CLASS.DOSE, y=ENSMUSG00000000001, fill=CLASS.DOSE)) +  geom_boxplot() +
  coord_flip() + labs(x = "Dose") + theme_solarized() + theme(legend.position="none")

ggplot(df,aes(x=CLASS.DOSE, y=ENSMUSG00000000001, fill=CLASS.DOSE)) +  geom_boxplot() +
  coord_flip() + labs(x = "Dose") + theme_economist() + theme(legend.position="none")

ggplot(df,aes(x=CLASS.DOSE, y=ENSMUSG00000000001, fill=CLASS.DOSE)) +  geom_boxplot() +
  coord_flip() + labs(x = "Dose") + theme_wsj() + theme(legend.position="none")

# Overlaying sampling points on boxplot
ggplot(df,aes(x=CLASS.DOSE, y=ENSMUSG00000000001, fill=CLASS.DOSE)) +  geom_boxplot() + 
  geom_jitter(color="black") + coord_flip() + labs(x = "Dose") + 
  theme_bw() + theme(legend.position="none",
                     text = element_text(size=20), 
                     axis.text.x = element_text(angle=45, hjust = 1))

# Change color and transparency
ggplot(df,aes(x=CLASS.DOSE, y=ENSMUSG00000000001, fill=CLASS.DOSE)) +  geom_boxplot(alpha=0.6) + 
  geom_jitter(color="black") + coord_flip() + labs(x = "Dose") + 
  theme_bw() + theme(legend.position="none",
                     text = element_text(size=20), 
                     axis.text.x = element_text(angle=45, hjust = 1)) +
  scale_fill_brewer(palette="PuBu") 

# Density Plots in ggplot
ggplot(df, aes(x=ENSMUSG00000000049, group=CLASS.DOSE, fill=CLASS.DOSE)) +
  geom_density() +
  labs(fill='Dose') +
  theme_bw() +
  theme(text = element_text(size=20)) +
  scale_fill_brewer(palette="Reds")  

ggplot(df, aes(x=ENSMUSG00000000049, group=CLASS.DOSE, fill=CLASS.DOSE)) +
  geom_density(alpha=0.4) +
  labs(fill='Dose') +
  theme_bw() +
  theme(text = element_text(size=20)) +
  scale_fill_brewer(palette="Reds") 

# Faceting
ggplot(df, aes(x=ENSMUSG00000000049, group=CLASS.DOSE, fill=CLASS.DOSE)) +
  geom_density() +
  theme_bw() +
  facet_wrap(~CLASS.DOSE) +
  theme(text = element_text(size=14),
        legend.position="none", 
        panel.spacing = unit(0.1, "lines")) +
  scale_fill_brewer(palette="Reds") 


# Plotting Spatial Dataset
usa <- map_data("usa")
# Getting the USA map
ggplot(usa, aes(x=long, y = lat, group = group)) + geom_polygon() + 
  coord_fixed(1.3) # coord_fixed will fix the aspect ratio

# Remove the fill
ggplot(usa, aes(x=long, y = lat, group = group)) + geom_polygon(fill = NA, color = "red") + 
  coord_fixed(1.3)

# Getting States on the map
states <- map_data("state")
head(states)

ggplot(states, aes(x = long, y = lat, fill = region, group = group)) + 
  geom_polygon(color = "white") + 
  coord_fixed(1.3) + labs(title = "US States", subtitle = "This is a blank map of the states.") +
  theme(legend.position="none")

# Isolating a state for plotting
ca_df <- subset(states, region == "california")
counties <- map_data("county")
ca_county <- subset(counties, region == "california")
head(ca_county)

ggplot(ca_df, aes(x = long, y = lat, group = group)) + 
  geom_polygon(data = ca_county, fill = "gray", color = "black") + coord_fixed(1.3) + 
  theme_bw() 

# Change the colors of counties
ggplot(ca_df, aes(x = long, y = lat, group = group)) + 
  geom_polygon(data = ca_county, aes(fill = subregion, alpha=0.6), color = "black") + 
  coord_fixed(1.3) + theme_bw() + theme(legend.position="none")

# find the centroid of the subregions
centroid <- aggregate(cbind(long,lat) ~ subregion, data=ca_county, FUN=mean)
head(centroid)

# Add labels to counties
ggplot(ca_df, aes(x = long, y = lat, group = group)) + 
  geom_polygon(data = ca_county, aes(fill = subregion, alpha=0.6), color = "black") + 
  geom_text(data = centroid, aes(x=long, y=lat, label=subregion),inherit.aes = FALSE, fontface = "bold") +
  coord_fixed(1.3) + theme_bw() + theme(legend.position="none")

select_counties <- c("los angeles", "san diego","monterey","santa barbara")
select_ca <-   centroid[centroid$subregion %in% select_counties,]

ggplot(ca_df, aes(x = long, y = lat, group = group)) + 
  geom_polygon(data = ca_county, aes(fill = subregion, alpha=0.6), color = "black") + 
  geom_text(data = select_ca, aes(x=long, y=lat, label=subregion),inherit.aes = FALSE, fontface = "bold") +
  coord_fixed(1.3) + theme_bw() + theme(legend.position="none")

library(ggrepel)
ggplot(ca_df, aes(x = long, y = lat, group = group)) + 
  geom_polygon(data = ca_county, aes(fill = subregion, alpha=0.6), color = "black") + 
  geom_text_repel(data = select_ca, aes(x = long, y = lat, label = subregion), inherit.aes = FALSE,
                fontface = "bold", nudge_x = c(-2, -2.2, -2, -3), nudge_y = c(-0.5,-0.8, -0.5, -0.5)) + 
  coord_fixed(1.3) + theme_bw() + theme(legend.position="none")

# Read region data
library(autoimage)
data(canada)
library(broom)
canada_df <- as.data.frame(tidy(canada))

# Plot sampling regions
env_data <- read.csv("~/Desktop/workshop/complex_exposure_raw_data.csv")
ggplot(canada_df, aes(x=long, y = lat, group = group)) + geom_polygon(fill="gray70", color="black") + 
  geom_point(data = env_data, aes(x = Long, y = Lat), inherit.aes = FALSE, size = 2, shape = 23, fill = "darkred") +
  coord_fixed(1.3) + theme_bw()

# Zoom into the region
ggplot(canada_df, aes(x=long, y = lat, group = group)) + geom_polygon(fill="gray70",color="black") + 
  geom_point(data = env_data, aes(x = Long, y = Lat), inherit.aes = FALSE, size = 2, shape = 23, fill = "darkred") +
  theme_bw() +
  coord_map(xlim=c(-122, -100), ylim=c(49, 62))

# Plot Lead Levels in samples and add titles
ggplot(canada_df, aes(x=long, y = lat, group = group)) + geom_polygon(fill=NA, color="black") + 
  geom_point(data = env_data, aes(x = Long, y = Lat, fill = Pb), inherit.aes = FALSE, size = 2, shape = 23) + 
  theme_bw() +
  coord_map(xlim=c(-122, -100), ylim=c(49, 62)) + 
  labs(title="Canadian Oil Sands Region", subtitle = "Chemical exposures among biota") +
  xlab("Longitude") +
  ylab("Latitude")

# Change Fill color
ggplot(canada_df, aes(x=long, y = lat, group = group)) + geom_polygon(fill=NA, color="black") + 
  geom_point(data = env_data, aes(x = Long, y = Lat, fill = Pb), inherit.aes = FALSE, size = 2, shape = 23) + 
  theme_bw() + coord_map(xlim=c(-122, -100), ylim=c(49, 62)) + 
  scale_fill_gradient(low = "dodgerblue", high = "firebrick4") + 
  labs(title="Canadian Oil Sands Region", subtitle = "Chemical exposures among biota") + 
  xlab("Longitude") +
  ylab("Latitude")

# Color samples based on species
env_data$Species <- factor(env_data$Species)
ggplot(canada_df, aes(x=long, y = lat, group = group)) + geom_polygon(fill=NA, color="black") + 
  geom_point(data = env_data, aes(x = Long, y = Lat, fill = Species), inherit.aes = FALSE, size = 2, shape = 23) + theme_bw() +
  coord_map(xlim=c(-122, -100), ylim=c(49, 62)) + 
  labs(title="Canadian Oil Sands Region", subtitle = "Chemical exposures among biota") + 
  xlab("Longitude") +
  ylab("Latitude")

# Saving plots
# png, pdf, etc. type saving lines are put before the ggplot command
png("Species.png", width = 8, height = 8, units="in",res = 500)
ggplot(canada_df, aes(x=long, y = lat, group = group)) + geom_polygon(fill=NA, color="black") + 
  geom_point(data = env_data, aes(x = Long, y = Lat, fill = Species), inherit.aes = FALSE, size = 2, shape = 23) + theme_bw() +
  coord_map(xlim=c(-122, -100), ylim=c(49, 62)) + 
  labs(title="Canadian Oil Sands Region", subtitle = "Chemical exposures among biota") + 
  xlab("Longitude") +
  ylab("Latitude")
dev.off()

# ggsave command is executed after ggplot command
ggplot(df, aes(x=ENSMUSG00000000049, group=CLASS.DOSE, fill=CLASS.DOSE)) +
  geom_density() +
  theme_bw() +
  facet_wrap(~CLASS.DOSE) +
  theme(text = element_text(size=14),
        legend.position="none", 
        panel.spacing = unit(0.1, "lines")) +
  scale_fill_brewer(palette="Reds") 
ggsave("DensityFacet.pdf", width = 6.5, height = 6, dpi = 600)

# Make sure to check your working directory. Files will be saved there.
getwd()

setwd("~/Desktop/workshop/")

# Interactive Plots
library(plotly)
myplot <- ggplot(df, aes(x=ENSMUSG00000000049, group=CLASS.DOSE, fill=CLASS.DOSE)) +
  geom_density() +
  theme_bw() +
  facet_wrap(~CLASS.DOSE) +
  theme(text = element_text(size=14),
        legend.position="none", 
        panel.spacing = unit(0.1, "lines")) +
  scale_fill_brewer(palette="Reds") 

ggplotly(myplot)

my_scatter <- ggplot(df, aes(ENSMUSG00000000001, ENSMUSG00000000028, colour = CLASS.DOSE)) + geom_point(size=3) +
              labs(col='Dose') +
              theme_bw() +
              theme(text = element_text(size=14))

ggplotly(my_scatter)


myboxplot <- ggplot(df,aes(x=CLASS.DOSE, y=ENSMUSG00000000001, fill=CLASS.DOSE)) +  geom_boxplot(alpha=0.6) + 
  geom_jitter(color="black") + coord_flip() + labs(x = "Dose") + 
  theme_bw() + theme(legend.position="none",
                     text = element_text(size=20), 
                     axis.text.x = element_text(angle=45, hjust = 1)) +
  scale_fill_brewer(palette="PuBu") 

ggplotly(myboxplot)


